@@ -8,7 +8,7 @@ from collections import defaultdict
 from openpyxl import load_workbook
 from xlrd import open_workbook
 
-__version__ = "0.4.2"
+__version__ = "0.5.1"
 
 if sys.platform != "win32":
     import signal
@@ -55,7 +55,10 @@ def get_stats(file, header: bool):
             array.sort()
             median = array[count // 2] if count % 2 else (array[count // 2] + array[count // 2 - 1]) / 2
             std = math.sqrt(sum((_ - mean)**2 for _ in array) / count)
-            n = max(min(4 - int(math.log10(median)), 4), 1)
+            if mean == 0:
+                n = 2
+            else:
+                n = max(min(4 - int(math.log10(mean)), 4), 1)
             stats[columns[i]] = [count, round(min_value, n), round(max_value, n), round(mean, n), round(median, n), round(std, n)]
         else:
             stats[columns[i]] = ["NA", "NA", "NA", "NA", "NA", "NA"]
@@ -66,25 +69,25 @@ def get_stats(file, header: bool):
         yield f"{item:6s}\t{out}"
 
 
-def get_view(file, limit: int, nlines: int):
+def get_view(file, width: int, nlines: int):
     rows = []
-    width = []
+    widths = []
     for i, line in enumerate(file, start=1):
         row = line.strip().split("\t")
         for index, string in enumerate(row):
-            if len(width) <= index:
-                width.append(len(string))
-            width[index] = min(limit, max(len(string), width[index]))
+            if len(widths) <= index:
+                widths.append(len(string))
+            widths[index] = min(width, max(len(string), widths[index]))
         rows.append(row)
         if nlines and i == nlines:
             break
     for row in rows:
         out_row = []
         for index, string in enumerate(row):
-            if len(string) < width[index]:
-                row[index] = string + " " * (width[index] - len(string))
+            if len(string) < widths[index]:
+                row[index] = string + " " * (widths[index] - len(string))
             else:
-                row[index] = string[:width[index]]
+                row[index] = string[:widths[index]]
             out_row.append(row[index])
         yield "  ".join(out_row)
 
@@ -161,8 +164,8 @@ def main():
     parser.add_argument("-p", "--pattern", type=str, help="pattern to match, wrap in single quotes")
     parser.add_argument("-a", "--add", type=str, help="add a new column with pattern, wrap in single quotes")
     parser.add_argument("-r", "--reorder", type=str, help="reorder columns, comma separated list of column numbers")
-    parser.add_argument("-l", "--limit", type=int, default=100, help="limit of column width, used with -v, 0 for unlimited, default: 100")
-    parser.add_argument("-n", "--nlines", type=int, default=100, help="max number of lines to view, used with -v, default: 100")
+    parser.add_argument("-w", "--width", type=int, default=100, help="limit of column width, used with -v, default: 100")
+    parser.add_argument("-n", "--nlines", type=int, default=100, help="max number of lines to view, used with -v, 0 for unlimited, default: 100")
     parser.add_argument("-V", "--version", action="version", version=__version__)
     args = parser.parse_args()
     file = get_file(args.input)
@@ -180,7 +183,7 @@ def main():
     if args.stat:
         file = get_stats(file, args.header)
     if args.view:
-        file = get_view(file, args.limit, args.nlines)
+        file = get_view(file, args.width, args.nlines)
     for line in file:
         print(line.strip())
 
